---
title: KG이니시스 허브형 간편결제 신청방법
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 간편결제
seo:
  title: KG이니시스 허브형 간편결제 신청방법
  description: >-
    KG이니시스에서는 다양한 간편결제사가 제휴되어 있어 이니시스를 통해 이용이 가능합니다. 간편결제사별로 심사 절차가 필요하므로 아래 경로로
    신청주시면 이니시스 담당 부서 확인 후 심사 및 설정 가능합니다.
  keywords:
    - KG이니시스
    - 간편결제
tags:
  - KG이니시스
  - 간편결제
pgCompanies:
  - KG이니시스
searchTags:
  - 허브형간편결제
  - 간편결제추가
  - KG이니시스간편결제
  - KG이니시스허브형
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="KG이니시스에서는 다양한 간편결제사가 제휴되어 있으며 서비스 신청 후 이용이 가능합니다.
" title="" />

### **KG이니시스 간편결제 상점아이디 추가**

KG이니시스에서는 다양한 간편결제사가 제휴되어있어 이니시스를 통해 이용이 가능합니다.\
다만, 간편결제사별로 심사 절차가 필요하므로 아래 경로로 신청주시면 이니시스 담당부서에서 확인 후 심사 및 설정 가능합니다.

<Callout icon="" content=" " title="KG이니시스 지원 허브형 간편결제 보러가기 ↗" />

### **KG이니시스 간편결제 추가 절차**

- [KG이니시스 상점관리자페이지↗](https://iniweb.inicis.com/) : 포트원용 KG이니시스 MID 로그인 > 우측 상단 \[변경/추가] > 1.2.1 지불수단 추가 및 변경 > 6. 간편결제 에서 이용하실 간편결제 서비스 체크 후 \[신청하기]

<Indent level="1">

- 네이버페이의 경우 간편결제 신청 시 요청사항 란에 ‘네이버페이 신청’으로 기입해 주시기 바랍니다.
- 허브형 간편결제는 정기결제방식은 제공하지 않습니다.

</Indent>

